pub struct Metadata {
pub computer: Option<String>,
pub time: Option<Time>,
pub extra_cper_sections: Vec<CperSectionBody>,
}Expand description
Crash Log Metadata
Fields
computer: Option<String>Name of the computer where the Crash Log has been extracted from.
time: Option<Time>Time of the extraction
extra_cper_sections: Vec<CperSectionBody>When the Crash Log is extracted from a CPER, this field stores the extra CPER sections that could be read from the CPER structure.